# coding: utf-8

"""
    Zadara VPSA Storage Array REST API

     # Overview  This document outlines the methods available for administrating your Zadara Storage VPSA&#8482;. The Zadara Storage Array REST API   supports form-encoded, JSON, and XML requests, and can return either JSON or XML responses.  ## Usage  The majority of the APIs available require authentication which requires an API token to use. You can retrieve this token through the   Users section of your VPSA, or through the API using the \"Return a user's access key\" API in the Users Section below.  ## Authentication Methods  The authentication token can be passed either through the access_key parameter inside of the body of the REST API request, or   through the X-Access-Key header.  ## Timeouts  By default, all operations that don't complete within five seconds will return a message informing you that the action may take some  time to complete. When using the API, this can cause some actions, such as large volume creation, to be undesirably asynchronous.  You can specify your own timeout with the timeout parameter, in seconds, and a timeout value of -1 specifies an infinite timeout.  ## Specific Fields For Product  Some of the fields/actions used in the API should be used only for a specific product. The following tags are used to mark which   product responds to the fields/actions  VPSA Flash Array  VPSA Storage Array - Hybrid VPSA  ## Questions  If you have any questions or need support involving the REST API, please contact for assistance.   # noqa: E501

    OpenAPI spec version: 23.03-sp1
    Contact: support@zadarastorage.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from Vpsa.api_client import ApiClient


class RemoteObjectStorageApi(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def backup_jobs_rate_limit(self, id, backup_jobs_rate_limit, **kwargs):  # noqa: E501
        """backup_jobs_rate_limit  # noqa: E501

        Update a object storage backup job rate limit (kb/s)  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.backup_jobs_rate_limit(id, backup_jobs_rate_limit, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: (required)
        :param BackupJobsRateLimit backup_jobs_rate_limit: (required)
        :return: InlineResponse200142
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.backup_jobs_rate_limit_with_http_info(id, backup_jobs_rate_limit, **kwargs)  # noqa: E501
        else:
            (data) = self.backup_jobs_rate_limit_with_http_info(id, backup_jobs_rate_limit, **kwargs)  # noqa: E501
            return data

    def backup_jobs_rate_limit_with_http_info(self, id, backup_jobs_rate_limit, **kwargs):  # noqa: E501
        """backup_jobs_rate_limit  # noqa: E501

        Update a object storage backup job rate limit (kb/s)  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.backup_jobs_rate_limit_with_http_info(id, backup_jobs_rate_limit, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: (required)
        :param BackupJobsRateLimit backup_jobs_rate_limit: (required)
        :return: InlineResponse200142
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['id', 'backup_jobs_rate_limit']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method backup_jobs_rate_limit" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'id' is set
        if self.api_client.client_side_validation and ('id' not in params or
                                                       params['id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `id` when calling `backup_jobs_rate_limit`")  # noqa: E501
        # verify the required parameter 'backup_jobs_rate_limit' is set
        if self.api_client.client_side_validation and ('backup_jobs_rate_limit' not in params or
                                                       params['backup_jobs_rate_limit'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `backup_jobs_rate_limit` when calling `backup_jobs_rate_limit`")  # noqa: E501

        if self.api_client.client_side_validation and ('id' in params and not re.search(r'^bkpjobs-[0-9a-f]{8}$', params['id'])):  # noqa: E501
            raise ValueError("Invalid value for parameter `id` when calling `backup_jobs_rate_limit`, must conform to the pattern `/^bkpjobs-[0-9a-f]{8}$/`")  # noqa: E501
        collection_formats = {}

        path_params = {}
        if 'id' in params:
            path_params['id'] = params['id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'backup_jobs_rate_limit' in params:
            body_params = params['backup_jobs_rate_limit']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api_key']  # noqa: E501

        return self.api_client.call_api(
            '/object_storage_backup_jobs/{id}/rate_limit.json', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='InlineResponse200142',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def backup_jobs_update_compression(self, id, backup_jobs_update_compression, **kwargs):  # noqa: E501
        """backup_jobs_update_compression  # noqa: E501

        Set compression for object storage backup job.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.backup_jobs_update_compression(id, backup_jobs_update_compression, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: (required)
        :param BackupJobsUpdateCompression backup_jobs_update_compression: (required)
        :return: InlineResponse200141
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.backup_jobs_update_compression_with_http_info(id, backup_jobs_update_compression, **kwargs)  # noqa: E501
        else:
            (data) = self.backup_jobs_update_compression_with_http_info(id, backup_jobs_update_compression, **kwargs)  # noqa: E501
            return data

    def backup_jobs_update_compression_with_http_info(self, id, backup_jobs_update_compression, **kwargs):  # noqa: E501
        """backup_jobs_update_compression  # noqa: E501

        Set compression for object storage backup job.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.backup_jobs_update_compression_with_http_info(id, backup_jobs_update_compression, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: (required)
        :param BackupJobsUpdateCompression backup_jobs_update_compression: (required)
        :return: InlineResponse200141
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['id', 'backup_jobs_update_compression']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method backup_jobs_update_compression" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'id' is set
        if self.api_client.client_side_validation and ('id' not in params or
                                                       params['id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `id` when calling `backup_jobs_update_compression`")  # noqa: E501
        # verify the required parameter 'backup_jobs_update_compression' is set
        if self.api_client.client_side_validation and ('backup_jobs_update_compression' not in params or
                                                       params['backup_jobs_update_compression'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `backup_jobs_update_compression` when calling `backup_jobs_update_compression`")  # noqa: E501

        if self.api_client.client_side_validation and ('id' in params and not re.search(r'^bkpjobs-[0-9a-f]{8}$', params['id'])):  # noqa: E501
            raise ValueError("Invalid value for parameter `id` when calling `backup_jobs_update_compression`, must conform to the pattern `/^bkpjobs-[0-9a-f]{8}$/`")  # noqa: E501
        collection_formats = {}

        path_params = {}
        if 'id' in params:
            path_params['id'] = params['id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'backup_jobs_update_compression' in params:
            body_params = params['backup_jobs_update_compression']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api_key']  # noqa: E501

        return self.api_client.call_api(
            '/object_storage_backup_jobs/{id}/compression.json', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='InlineResponse200141',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def break_ros_backup_job(self, id, break_ros_backup_job, **kwargs):  # noqa: E501
        """break_ros_backup_job  # noqa: E501

        Break object storage backup job.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.break_ros_backup_job(id, break_ros_backup_job, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: (required)
        :param BreakRosBackupJob break_ros_backup_job: (required)
        :return: InlineResponse200140
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.break_ros_backup_job_with_http_info(id, break_ros_backup_job, **kwargs)  # noqa: E501
        else:
            (data) = self.break_ros_backup_job_with_http_info(id, break_ros_backup_job, **kwargs)  # noqa: E501
            return data

    def break_ros_backup_job_with_http_info(self, id, break_ros_backup_job, **kwargs):  # noqa: E501
        """break_ros_backup_job  # noqa: E501

        Break object storage backup job.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.break_ros_backup_job_with_http_info(id, break_ros_backup_job, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: (required)
        :param BreakRosBackupJob break_ros_backup_job: (required)
        :return: InlineResponse200140
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['id', 'break_ros_backup_job']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method break_ros_backup_job" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'id' is set
        if self.api_client.client_side_validation and ('id' not in params or
                                                       params['id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `id` when calling `break_ros_backup_job`")  # noqa: E501
        # verify the required parameter 'break_ros_backup_job' is set
        if self.api_client.client_side_validation and ('break_ros_backup_job' not in params or
                                                       params['break_ros_backup_job'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `break_ros_backup_job` when calling `break_ros_backup_job`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'id' in params:
            path_params['id'] = params['id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'break_ros_backup_job' in params:
            body_params = params['break_ros_backup_job']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api_key']  # noqa: E501

        return self.api_client.call_api(
            '/object_storage_backup_jobs/{id}/break.json', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='InlineResponse200140',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def break_ros_restore_job(self, id, **kwargs):  # noqa: E501
        """break_ros_restore_job  # noqa: E501

        Break object storage restore job.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.break_ros_restore_job(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: (required)
        :return: InlineResponse200150
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.break_ros_restore_job_with_http_info(id, **kwargs)  # noqa: E501
        else:
            (data) = self.break_ros_restore_job_with_http_info(id, **kwargs)  # noqa: E501
            return data

    def break_ros_restore_job_with_http_info(self, id, **kwargs):  # noqa: E501
        """break_ros_restore_job  # noqa: E501

        Break object storage restore job.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.break_ros_restore_job_with_http_info(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: (required)
        :return: InlineResponse200150
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method break_ros_restore_job" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'id' is set
        if self.api_client.client_side_validation and ('id' not in params or
                                                       params['id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `id` when calling `break_ros_restore_job`")  # noqa: E501

        if self.api_client.client_side_validation and ('id' in params and not re.search(r'^rstjobs-[0-9a-f]{8}$', params['id'])):  # noqa: E501
            raise ValueError("Invalid value for parameter `id` when calling `break_ros_restore_job`, must conform to the pattern `/^rstjobs-[0-9a-f]{8}$/`")  # noqa: E501
        collection_formats = {}

        path_params = {}
        if 'id' in params:
            path_params['id'] = params['id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api_key']  # noqa: E501

        return self.api_client.call_api(
            '/object_storage_restore_jobs/{id}/break.json', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='InlineResponse200150',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def change_ros_restore_job_mode(self, id, change_ros_restore_job_mode, **kwargs):  # noqa: E501
        """change_ros_restore_job_mode  # noqa: E501

        Set restore mode for object storage restore job.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.change_ros_restore_job_mode(id, change_ros_restore_job_mode, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: (required)
        :param ChangeRosRestoreJobMode change_ros_restore_job_mode: (required)
        :return: InlineResponse200151
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.change_ros_restore_job_mode_with_http_info(id, change_ros_restore_job_mode, **kwargs)  # noqa: E501
        else:
            (data) = self.change_ros_restore_job_mode_with_http_info(id, change_ros_restore_job_mode, **kwargs)  # noqa: E501
            return data

    def change_ros_restore_job_mode_with_http_info(self, id, change_ros_restore_job_mode, **kwargs):  # noqa: E501
        """change_ros_restore_job_mode  # noqa: E501

        Set restore mode for object storage restore job.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.change_ros_restore_job_mode_with_http_info(id, change_ros_restore_job_mode, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: (required)
        :param ChangeRosRestoreJobMode change_ros_restore_job_mode: (required)
        :return: InlineResponse200151
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['id', 'change_ros_restore_job_mode']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method change_ros_restore_job_mode" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'id' is set
        if self.api_client.client_side_validation and ('id' not in params or
                                                       params['id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `id` when calling `change_ros_restore_job_mode`")  # noqa: E501
        # verify the required parameter 'change_ros_restore_job_mode' is set
        if self.api_client.client_side_validation and ('change_ros_restore_job_mode' not in params or
                                                       params['change_ros_restore_job_mode'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `change_ros_restore_job_mode` when calling `change_ros_restore_job_mode`")  # noqa: E501

        if self.api_client.client_side_validation and ('id' in params and not re.search(r'^rstjobs-[0-9a-f]{8}$', params['id'])):  # noqa: E501
            raise ValueError("Invalid value for parameter `id` when calling `change_ros_restore_job_mode`, must conform to the pattern `/^rstjobs-[0-9a-f]{8}$/`")  # noqa: E501
        collection_formats = {}

        path_params = {}
        if 'id' in params:
            path_params['id'] = params['id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'change_ros_restore_job_mode' in params:
            body_params = params['change_ros_restore_job_mode']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api_key']  # noqa: E501

        return self.api_client.call_api(
            '/object_storage_restore_jobs/{id}/switch_mode.json', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='InlineResponse200151',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def create_ros_backup_job(self, create_ros_backup_job, **kwargs):  # noqa: E501
        """create_ros_backup_job  # noqa: E501

        Create cloud object storage backup job.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.create_ros_backup_job(create_ros_backup_job, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param CreateRosBackupJob create_ros_backup_job: (required)
        :return: InlineResponse200135
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.create_ros_backup_job_with_http_info(create_ros_backup_job, **kwargs)  # noqa: E501
        else:
            (data) = self.create_ros_backup_job_with_http_info(create_ros_backup_job, **kwargs)  # noqa: E501
            return data

    def create_ros_backup_job_with_http_info(self, create_ros_backup_job, **kwargs):  # noqa: E501
        """create_ros_backup_job  # noqa: E501

        Create cloud object storage backup job.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.create_ros_backup_job_with_http_info(create_ros_backup_job, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param CreateRosBackupJob create_ros_backup_job: (required)
        :return: InlineResponse200135
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['create_ros_backup_job']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method create_ros_backup_job" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'create_ros_backup_job' is set
        if self.api_client.client_side_validation and ('create_ros_backup_job' not in params or
                                                       params['create_ros_backup_job'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `create_ros_backup_job` when calling `create_ros_backup_job`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'create_ros_backup_job' in params:
            body_params = params['create_ros_backup_job']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api_key']  # noqa: E501

        return self.api_client.call_api(
            '/object_storage_backup_jobs.json', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='InlineResponse200135',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def create_ros_destination(self, create_ros_destination, **kwargs):  # noqa: E501
        """create_ros_destination  # noqa: E501

        Create a remote object storage.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.create_ros_destination(create_ros_destination, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param CreateRosDestination create_ros_destination: (required)
        :return: InlineResponse200128
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.create_ros_destination_with_http_info(create_ros_destination, **kwargs)  # noqa: E501
        else:
            (data) = self.create_ros_destination_with_http_info(create_ros_destination, **kwargs)  # noqa: E501
            return data

    def create_ros_destination_with_http_info(self, create_ros_destination, **kwargs):  # noqa: E501
        """create_ros_destination  # noqa: E501

        Create a remote object storage.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.create_ros_destination_with_http_info(create_ros_destination, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param CreateRosDestination create_ros_destination: (required)
        :return: InlineResponse200128
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['create_ros_destination']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method create_ros_destination" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'create_ros_destination' is set
        if self.api_client.client_side_validation and ('create_ros_destination' not in params or
                                                       params['create_ros_destination'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `create_ros_destination` when calling `create_ros_destination`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'create_ros_destination' in params:
            body_params = params['create_ros_destination']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api_key']  # noqa: E501

        return self.api_client.call_api(
            '/object_storage_destinations.json', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='InlineResponse200128',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def create_ros_restore_job(self, create_ros_restore_job, **kwargs):  # noqa: E501
        """create_ros_restore_job  # noqa: E501

        Create object storage restore job. Can be created from object storage key or from object storage snapshot name (key or local_snapname must be supplied)  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.create_ros_restore_job(create_ros_restore_job, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param CreateRosRestoreJob create_ros_restore_job: (required)
        :return: InlineResponse200146
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.create_ros_restore_job_with_http_info(create_ros_restore_job, **kwargs)  # noqa: E501
        else:
            (data) = self.create_ros_restore_job_with_http_info(create_ros_restore_job, **kwargs)  # noqa: E501
            return data

    def create_ros_restore_job_with_http_info(self, create_ros_restore_job, **kwargs):  # noqa: E501
        """create_ros_restore_job  # noqa: E501

        Create object storage restore job. Can be created from object storage key or from object storage snapshot name (key or local_snapname must be supplied)  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.create_ros_restore_job_with_http_info(create_ros_restore_job, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param CreateRosRestoreJob create_ros_restore_job: (required)
        :return: InlineResponse200146
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['create_ros_restore_job']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method create_ros_restore_job" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'create_ros_restore_job' is set
        if self.api_client.client_side_validation and ('create_ros_restore_job' not in params or
                                                       params['create_ros_restore_job'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `create_ros_restore_job` when calling `create_ros_restore_job`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'create_ros_restore_job' in params:
            body_params = params['create_ros_restore_job']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api_key']  # noqa: E501

        return self.api_client.call_api(
            '/object_storage_restore_jobs.json', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='InlineResponse200146',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_all_ros_backup_jobs(self, **kwargs):  # noqa: E501
        """get_all_ros_backup_jobs  # noqa: E501

        Returns a list of all Object Storage backup jobs.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_all_ros_backup_jobs(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int start: The item number to start from. 0 starts from the beginning.
        :param int limit: The total number of records to return.
        :return: InlineResponse200134
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_all_ros_backup_jobs_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.get_all_ros_backup_jobs_with_http_info(**kwargs)  # noqa: E501
            return data

    def get_all_ros_backup_jobs_with_http_info(self, **kwargs):  # noqa: E501
        """get_all_ros_backup_jobs  # noqa: E501

        Returns a list of all Object Storage backup jobs.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_all_ros_backup_jobs_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int start: The item number to start from. 0 starts from the beginning.
        :param int limit: The total number of records to return.
        :return: InlineResponse200134
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['start', 'limit']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_all_ros_backup_jobs" % key
                )
            params[key] = val
        del params['kwargs']

        if self.api_client.client_side_validation and ('start' in params and params['start'] < 0):  # noqa: E501
            raise ValueError("Invalid value for parameter `start` when calling `get_all_ros_backup_jobs`, must be a value greater than or equal to `0`")  # noqa: E501
        collection_formats = {}

        path_params = {}

        query_params = []
        if 'start' in params:
            query_params.append(('start', params['start']))  # noqa: E501
        if 'limit' in params:
            query_params.append(('limit', params['limit']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api_key']  # noqa: E501

        return self.api_client.call_api(
            '/object_storage_backup_jobs.json', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='InlineResponse200134',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_all_ros_destination_backup_jobs(self, id, **kwargs):  # noqa: E501
        """get_all_ros_destination_backup_jobs  # noqa: E501

        Returns a list of all backup jobs of one specific object storage destination.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_all_ros_destination_backup_jobs(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: (required)
        :return: InlineResponse200132
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_all_ros_destination_backup_jobs_with_http_info(id, **kwargs)  # noqa: E501
        else:
            (data) = self.get_all_ros_destination_backup_jobs_with_http_info(id, **kwargs)  # noqa: E501
            return data

    def get_all_ros_destination_backup_jobs_with_http_info(self, id, **kwargs):  # noqa: E501
        """get_all_ros_destination_backup_jobs  # noqa: E501

        Returns a list of all backup jobs of one specific object storage destination.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_all_ros_destination_backup_jobs_with_http_info(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: (required)
        :return: InlineResponse200132
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_all_ros_destination_backup_jobs" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'id' is set
        if self.api_client.client_side_validation and ('id' not in params or
                                                       params['id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `id` when calling `get_all_ros_destination_backup_jobs`")  # noqa: E501

        if self.api_client.client_side_validation and ('id' in params and not re.search(r'^obsdst-[0-9a-f]{8}$', params['id'])):  # noqa: E501
            raise ValueError("Invalid value for parameter `id` when calling `get_all_ros_destination_backup_jobs`, must conform to the pattern `/^obsdst-[0-9a-f]{8}$/`")  # noqa: E501
        collection_formats = {}

        path_params = {}
        if 'id' in params:
            path_params['id'] = params['id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api_key']  # noqa: E501

        return self.api_client.call_api(
            '/object_storage_destinations/{id}/backup_jobs.json', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='InlineResponse200132',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_all_ros_destination_restore_jobs(self, id, **kwargs):  # noqa: E501
        """get_all_ros_destination_restore_jobs  # noqa: E501

        Returns a list of all restore jobs of one specific Object Storage destination.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_all_ros_destination_restore_jobs(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: (required)
        :return: InlineResponse200133
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_all_ros_destination_restore_jobs_with_http_info(id, **kwargs)  # noqa: E501
        else:
            (data) = self.get_all_ros_destination_restore_jobs_with_http_info(id, **kwargs)  # noqa: E501
            return data

    def get_all_ros_destination_restore_jobs_with_http_info(self, id, **kwargs):  # noqa: E501
        """get_all_ros_destination_restore_jobs  # noqa: E501

        Returns a list of all restore jobs of one specific Object Storage destination.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_all_ros_destination_restore_jobs_with_http_info(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: (required)
        :return: InlineResponse200133
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_all_ros_destination_restore_jobs" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'id' is set
        if self.api_client.client_side_validation and ('id' not in params or
                                                       params['id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `id` when calling `get_all_ros_destination_restore_jobs`")  # noqa: E501

        if self.api_client.client_side_validation and ('id' in params and not re.search(r'^obsdst-[0-9a-f]{8}$', params['id'])):  # noqa: E501
            raise ValueError("Invalid value for parameter `id` when calling `get_all_ros_destination_restore_jobs`, must conform to the pattern `/^obsdst-[0-9a-f]{8}$/`")  # noqa: E501
        collection_formats = {}

        path_params = {}
        if 'id' in params:
            path_params['id'] = params['id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api_key']  # noqa: E501

        return self.api_client.call_api(
            '/object_storage_destinations/{id}/restore_jobs.json', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='InlineResponse200133',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_all_ros_destinations(self, **kwargs):  # noqa: E501
        """get_all_ros_destinations  # noqa: E501

        Returns a List of all remote Object Storages.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_all_ros_destinations(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int start: The item number to start from. 0 starts from the beginning.
        :param int limit: The total number of records to return.
        :return: InlineResponse200127
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_all_ros_destinations_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.get_all_ros_destinations_with_http_info(**kwargs)  # noqa: E501
            return data

    def get_all_ros_destinations_with_http_info(self, **kwargs):  # noqa: E501
        """get_all_ros_destinations  # noqa: E501

        Returns a List of all remote Object Storages.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_all_ros_destinations_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int start: The item number to start from. 0 starts from the beginning.
        :param int limit: The total number of records to return.
        :return: InlineResponse200127
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['start', 'limit']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_all_ros_destinations" % key
                )
            params[key] = val
        del params['kwargs']

        if self.api_client.client_side_validation and ('start' in params and params['start'] < 0):  # noqa: E501
            raise ValueError("Invalid value for parameter `start` when calling `get_all_ros_destinations`, must be a value greater than or equal to `0`")  # noqa: E501
        collection_formats = {}

        path_params = {}

        query_params = []
        if 'start' in params:
            query_params.append(('start', params['start']))  # noqa: E501
        if 'limit' in params:
            query_params.append(('limit', params['limit']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api_key']  # noqa: E501

        return self.api_client.call_api(
            '/object_storage_destinations.json', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='InlineResponse200127',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_all_ros_restore_jobs(self, **kwargs):  # noqa: E501
        """get_all_ros_restore_jobs  # noqa: E501

        Returns a List of all Object Storage restore jobs.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_all_ros_restore_jobs(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :return: InlineResponse200145
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_all_ros_restore_jobs_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.get_all_ros_restore_jobs_with_http_info(**kwargs)  # noqa: E501
            return data

    def get_all_ros_restore_jobs_with_http_info(self, **kwargs):  # noqa: E501
        """get_all_ros_restore_jobs  # noqa: E501

        Returns a List of all Object Storage restore jobs.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_all_ros_restore_jobs_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :return: InlineResponse200145
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = []  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_all_ros_restore_jobs" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api_key']  # noqa: E501

        return self.api_client.call_api(
            '/object_storage_restore_jobs.json', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='InlineResponse200145',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_ros_backup_job(self, id, **kwargs):  # noqa: E501
        """get_ros_backup_job  # noqa: E501

        Returns the details of Object Storage backup job.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_ros_backup_job(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: (required)
        :return: InlineResponse200136
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_ros_backup_job_with_http_info(id, **kwargs)  # noqa: E501
        else:
            (data) = self.get_ros_backup_job_with_http_info(id, **kwargs)  # noqa: E501
            return data

    def get_ros_backup_job_with_http_info(self, id, **kwargs):  # noqa: E501
        """get_ros_backup_job  # noqa: E501

        Returns the details of Object Storage backup job.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_ros_backup_job_with_http_info(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: (required)
        :return: InlineResponse200136
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_ros_backup_job" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'id' is set
        if self.api_client.client_side_validation and ('id' not in params or
                                                       params['id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `id` when calling `get_ros_backup_job`")  # noqa: E501

        if self.api_client.client_side_validation and ('id' in params and not re.search(r'^bkpjobs-[0-9a-f]{8}$', params['id'])):  # noqa: E501
            raise ValueError("Invalid value for parameter `id` when calling `get_ros_backup_job`, must conform to the pattern `/^bkpjobs-[0-9a-f]{8}$/`")  # noqa: E501
        collection_formats = {}

        path_params = {}
        if 'id' in params:
            path_params['id'] = params['id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api_key']  # noqa: E501

        return self.api_client.call_api(
            '/object_storage_backup_jobs/{id}.json', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='InlineResponse200136',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_ros_backup_job_performance(self, id, **kwargs):  # noqa: E501
        """get_ros_backup_job_performance  # noqa: E501

        Returns the details for Object Storage backup job performance.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_ros_backup_job_performance(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: (required)
        :param int interval: The interval between data points, in seconds
        :return: InlineResponse200144
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_ros_backup_job_performance_with_http_info(id, **kwargs)  # noqa: E501
        else:
            (data) = self.get_ros_backup_job_performance_with_http_info(id, **kwargs)  # noqa: E501
            return data

    def get_ros_backup_job_performance_with_http_info(self, id, **kwargs):  # noqa: E501
        """get_ros_backup_job_performance  # noqa: E501

        Returns the details for Object Storage backup job performance.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_ros_backup_job_performance_with_http_info(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: (required)
        :param int interval: The interval between data points, in seconds
        :return: InlineResponse200144
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['id', 'interval']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_ros_backup_job_performance" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'id' is set
        if self.api_client.client_side_validation and ('id' not in params or
                                                       params['id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `id` when calling `get_ros_backup_job_performance`")  # noqa: E501

        if self.api_client.client_side_validation and ('id' in params and not re.search(r'^bkpjobs-[0-9a-f]{8}$', params['id'])):  # noqa: E501
            raise ValueError("Invalid value for parameter `id` when calling `get_ros_backup_job_performance`, must conform to the pattern `/^bkpjobs-[0-9a-f]{8}$/`")  # noqa: E501
        if self.api_client.client_side_validation and ('interval' in params and params['interval'] < 1):  # noqa: E501
            raise ValueError("Invalid value for parameter `interval` when calling `get_ros_backup_job_performance`, must be a value greater than or equal to `1`")  # noqa: E501
        collection_formats = {}

        path_params = {}
        if 'id' in params:
            path_params['id'] = params['id']  # noqa: E501

        query_params = []
        if 'interval' in params:
            query_params.append(('interval', params['interval']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api_key']  # noqa: E501

        return self.api_client.call_api(
            '/object_storage_backup_jobs/{id}/performance.json', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='InlineResponse200144',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_ros_destination(self, id, **kwargs):  # noqa: E501
        """get_ros_destination  # noqa: E501

        Returns the details for a specific Object Storage destinations.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_ros_destination(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: (required)
        :return: InlineResponse200129
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_ros_destination_with_http_info(id, **kwargs)  # noqa: E501
        else:
            (data) = self.get_ros_destination_with_http_info(id, **kwargs)  # noqa: E501
            return data

    def get_ros_destination_with_http_info(self, id, **kwargs):  # noqa: E501
        """get_ros_destination  # noqa: E501

        Returns the details for a specific Object Storage destinations.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_ros_destination_with_http_info(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: (required)
        :return: InlineResponse200129
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_ros_destination" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'id' is set
        if self.api_client.client_side_validation and ('id' not in params or
                                                       params['id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `id` when calling `get_ros_destination`")  # noqa: E501

        if self.api_client.client_side_validation and ('id' in params and not re.search(r'^obsdst-[0-9a-f]{8}$', params['id'])):  # noqa: E501
            raise ValueError("Invalid value for parameter `id` when calling `get_ros_destination`, must conform to the pattern `/^obsdst-[0-9a-f]{8}$/`")  # noqa: E501
        collection_formats = {}

        path_params = {}
        if 'id' in params:
            path_params['id'] = params['id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api_key']  # noqa: E501

        return self.api_client.call_api(
            '/object_storage_destinations/{id}.json', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='InlineResponse200129',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_ros_restore_job(self, id, **kwargs):  # noqa: E501
        """get_ros_restore_job  # noqa: E501

        Returns the details for Object Storage restore job.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_ros_restore_job(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: (required)
        :return: InlineResponse200147
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_ros_restore_job_with_http_info(id, **kwargs)  # noqa: E501
        else:
            (data) = self.get_ros_restore_job_with_http_info(id, **kwargs)  # noqa: E501
            return data

    def get_ros_restore_job_with_http_info(self, id, **kwargs):  # noqa: E501
        """get_ros_restore_job  # noqa: E501

        Returns the details for Object Storage restore job.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_ros_restore_job_with_http_info(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: (required)
        :return: InlineResponse200147
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_ros_restore_job" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'id' is set
        if self.api_client.client_side_validation and ('id' not in params or
                                                       params['id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `id` when calling `get_ros_restore_job`")  # noqa: E501

        if self.api_client.client_side_validation and ('id' in params and not re.search(r'^rstjobs-[0-9a-f]{8}$', params['id'])):  # noqa: E501
            raise ValueError("Invalid value for parameter `id` when calling `get_ros_restore_job`, must conform to the pattern `/^rstjobs-[0-9a-f]{8}$/`")  # noqa: E501
        collection_formats = {}

        path_params = {}
        if 'id' in params:
            path_params['id'] = params['id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api_key']  # noqa: E501

        return self.api_client.call_api(
            '/object_storage_restore_jobs/{id}.json', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='InlineResponse200147',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_ros_restore_job_performance(self, id, **kwargs):  # noqa: E501
        """get_ros_restore_job_performance  # noqa: E501

        Returns the details for Object Storage restore job performance.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_ros_restore_job_performance(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: (required)
        :param str interval: Interval in seconds between metered data
        :return: InlineResponse200152
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_ros_restore_job_performance_with_http_info(id, **kwargs)  # noqa: E501
        else:
            (data) = self.get_ros_restore_job_performance_with_http_info(id, **kwargs)  # noqa: E501
            return data

    def get_ros_restore_job_performance_with_http_info(self, id, **kwargs):  # noqa: E501
        """get_ros_restore_job_performance  # noqa: E501

        Returns the details for Object Storage restore job performance.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_ros_restore_job_performance_with_http_info(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: (required)
        :param str interval: Interval in seconds between metered data
        :return: InlineResponse200152
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['id', 'interval']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_ros_restore_job_performance" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'id' is set
        if self.api_client.client_side_validation and ('id' not in params or
                                                       params['id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `id` when calling `get_ros_restore_job_performance`")  # noqa: E501

        if self.api_client.client_side_validation and ('id' in params and not re.search(r'^rstjobs-[0-9a-f]{8}$', params['id'])):  # noqa: E501
            raise ValueError("Invalid value for parameter `id` when calling `get_ros_restore_job_performance`, must conform to the pattern `/^rstjobs-[0-9a-f]{8}$/`")  # noqa: E501
        if self.api_client.client_side_validation and ('interval' in params and params['interval'] < 1):  # noqa: E501
            raise ValueError("Invalid value for parameter `interval` when calling `get_ros_restore_job_performance`, must be a value greater than or equal to `1`")  # noqa: E501
        collection_formats = {}

        path_params = {}
        if 'id' in params:
            path_params['id'] = params['id']  # noqa: E501

        query_params = []
        if 'interval' in params:
            query_params.append(('interval', params['interval']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api_key']  # noqa: E501

        return self.api_client.call_api(
            '/object_storage_restore_jobs/{id}/performance.json', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='InlineResponse200152',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def pause_ros_backup_job(self, id, **kwargs):  # noqa: E501
        """pause_ros_backup_job  # noqa: E501

        Pause object storage backup job.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.pause_ros_backup_job(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: (required)
        :return: InlineResponse200137
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.pause_ros_backup_job_with_http_info(id, **kwargs)  # noqa: E501
        else:
            (data) = self.pause_ros_backup_job_with_http_info(id, **kwargs)  # noqa: E501
            return data

    def pause_ros_backup_job_with_http_info(self, id, **kwargs):  # noqa: E501
        """pause_ros_backup_job  # noqa: E501

        Pause object storage backup job.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.pause_ros_backup_job_with_http_info(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: (required)
        :return: InlineResponse200137
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method pause_ros_backup_job" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'id' is set
        if self.api_client.client_side_validation and ('id' not in params or
                                                       params['id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `id` when calling `pause_ros_backup_job`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'id' in params:
            path_params['id'] = params['id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api_key']  # noqa: E501

        return self.api_client.call_api(
            '/object_storage_backup_jobs/{id}/pause.json', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='InlineResponse200137',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def pause_ros_restore_job(self, id, **kwargs):  # noqa: E501
        """pause_ros_restore_job  # noqa: E501

        Pause object storage restore job.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.pause_ros_restore_job(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: (required)
        :return: InlineResponse200148
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.pause_ros_restore_job_with_http_info(id, **kwargs)  # noqa: E501
        else:
            (data) = self.pause_ros_restore_job_with_http_info(id, **kwargs)  # noqa: E501
            return data

    def pause_ros_restore_job_with_http_info(self, id, **kwargs):  # noqa: E501
        """pause_ros_restore_job  # noqa: E501

        Pause object storage restore job.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.pause_ros_restore_job_with_http_info(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: (required)
        :return: InlineResponse200148
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method pause_ros_restore_job" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'id' is set
        if self.api_client.client_side_validation and ('id' not in params or
                                                       params['id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `id` when calling `pause_ros_restore_job`")  # noqa: E501

        if self.api_client.client_side_validation and ('id' in params and not re.search(r'^rstjobs-[0-9a-f]{8}$', params['id'])):  # noqa: E501
            raise ValueError("Invalid value for parameter `id` when calling `pause_ros_restore_job`, must conform to the pattern `/^rstjobs-[0-9a-f]{8}$/`")  # noqa: E501
        collection_formats = {}

        path_params = {}
        if 'id' in params:
            path_params['id'] = params['id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api_key']  # noqa: E501

        return self.api_client.call_api(
            '/object_storage_restore_jobs/{id}/pause.json', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='InlineResponse200148',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def remove_ros_destination(self, id, **kwargs):  # noqa: E501
        """remove_ros_destination  # noqa: E501

        Delete a remote object storage.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.remove_ros_destination(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: (required)
        :return: InlineResponse200131
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.remove_ros_destination_with_http_info(id, **kwargs)  # noqa: E501
        else:
            (data) = self.remove_ros_destination_with_http_info(id, **kwargs)  # noqa: E501
            return data

    def remove_ros_destination_with_http_info(self, id, **kwargs):  # noqa: E501
        """remove_ros_destination  # noqa: E501

        Delete a remote object storage.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.remove_ros_destination_with_http_info(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: (required)
        :return: InlineResponse200131
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method remove_ros_destination" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'id' is set
        if self.api_client.client_side_validation and ('id' not in params or
                                                       params['id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `id` when calling `remove_ros_destination`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'id' in params:
            path_params['id'] = params['id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api_key']  # noqa: E501

        return self.api_client.call_api(
            '/object_storage_destinations/{id}.json', 'DELETE',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='InlineResponse200131',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def replace_ros_backup_job_snapshot_policy(self, id, replace_ros_backup_job_snapshot_policy, **kwargs):  # noqa: E501
        """replace_ros_backup_job_snapshot_policy  # noqa: E501

        Replace snapshot policy for object storage backup job.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.replace_ros_backup_job_snapshot_policy(id, replace_ros_backup_job_snapshot_policy, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: (required)
        :param ReplaceRosBackupJobSnapshotPolicy replace_ros_backup_job_snapshot_policy: (required)
        :return: InlineResponse200143
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.replace_ros_backup_job_snapshot_policy_with_http_info(id, replace_ros_backup_job_snapshot_policy, **kwargs)  # noqa: E501
        else:
            (data) = self.replace_ros_backup_job_snapshot_policy_with_http_info(id, replace_ros_backup_job_snapshot_policy, **kwargs)  # noqa: E501
            return data

    def replace_ros_backup_job_snapshot_policy_with_http_info(self, id, replace_ros_backup_job_snapshot_policy, **kwargs):  # noqa: E501
        """replace_ros_backup_job_snapshot_policy  # noqa: E501

        Replace snapshot policy for object storage backup job.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.replace_ros_backup_job_snapshot_policy_with_http_info(id, replace_ros_backup_job_snapshot_policy, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: (required)
        :param ReplaceRosBackupJobSnapshotPolicy replace_ros_backup_job_snapshot_policy: (required)
        :return: InlineResponse200143
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['id', 'replace_ros_backup_job_snapshot_policy']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method replace_ros_backup_job_snapshot_policy" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'id' is set
        if self.api_client.client_side_validation and ('id' not in params or
                                                       params['id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `id` when calling `replace_ros_backup_job_snapshot_policy`")  # noqa: E501
        # verify the required parameter 'replace_ros_backup_job_snapshot_policy' is set
        if self.api_client.client_side_validation and ('replace_ros_backup_job_snapshot_policy' not in params or
                                                       params['replace_ros_backup_job_snapshot_policy'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `replace_ros_backup_job_snapshot_policy` when calling `replace_ros_backup_job_snapshot_policy`")  # noqa: E501

        if self.api_client.client_side_validation and ('id' in params and not re.search(r'^bkpjobs-[0-9a-f]{8}$', params['id'])):  # noqa: E501
            raise ValueError("Invalid value for parameter `id` when calling `replace_ros_backup_job_snapshot_policy`, must conform to the pattern `/^bkpjobs-[0-9a-f]{8}$/`")  # noqa: E501
        collection_formats = {}

        path_params = {}
        if 'id' in params:
            path_params['id'] = params['id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'replace_ros_backup_job_snapshot_policy' in params:
            body_params = params['replace_ros_backup_job_snapshot_policy']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api_key']  # noqa: E501

        return self.api_client.call_api(
            '/object_storage_backup_jobs/{id}/replace_snapshot_policy.json', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='InlineResponse200143',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def resume_ros_backup_job(self, id, **kwargs):  # noqa: E501
        """resume_ros_backup_job  # noqa: E501

        Continue object storage backup job.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.resume_ros_backup_job(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: (required)
        :return: InlineResponse200139
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.resume_ros_backup_job_with_http_info(id, **kwargs)  # noqa: E501
        else:
            (data) = self.resume_ros_backup_job_with_http_info(id, **kwargs)  # noqa: E501
            return data

    def resume_ros_backup_job_with_http_info(self, id, **kwargs):  # noqa: E501
        """resume_ros_backup_job  # noqa: E501

        Continue object storage backup job.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.resume_ros_backup_job_with_http_info(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: (required)
        :return: InlineResponse200139
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method resume_ros_backup_job" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'id' is set
        if self.api_client.client_side_validation and ('id' not in params or
                                                       params['id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `id` when calling `resume_ros_backup_job`")  # noqa: E501

        if self.api_client.client_side_validation and ('id' in params and not re.search(r'^bkpjobs-[0-9a-f]{8}$', params['id'])):  # noqa: E501
            raise ValueError("Invalid value for parameter `id` when calling `resume_ros_backup_job`, must conform to the pattern `/^bkpjobs-[0-9a-f]{8}$/`")  # noqa: E501
        collection_formats = {}

        path_params = {}
        if 'id' in params:
            path_params['id'] = params['id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api_key']  # noqa: E501

        return self.api_client.call_api(
            '/object_storage_backup_jobs/{id}/continue.json', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='InlineResponse200139',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def resume_ros_restore_job(self, id, **kwargs):  # noqa: E501
        """resume_ros_restore_job  # noqa: E501

        Continue object storage restore job.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.resume_ros_restore_job(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: (required)
        :return: InlineResponse200149
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.resume_ros_restore_job_with_http_info(id, **kwargs)  # noqa: E501
        else:
            (data) = self.resume_ros_restore_job_with_http_info(id, **kwargs)  # noqa: E501
            return data

    def resume_ros_restore_job_with_http_info(self, id, **kwargs):  # noqa: E501
        """resume_ros_restore_job  # noqa: E501

        Continue object storage restore job.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.resume_ros_restore_job_with_http_info(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: (required)
        :return: InlineResponse200149
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method resume_ros_restore_job" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'id' is set
        if self.api_client.client_side_validation and ('id' not in params or
                                                       params['id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `id` when calling `resume_ros_restore_job`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'id' in params:
            path_params['id'] = params['id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api_key']  # noqa: E501

        return self.api_client.call_api(
            '/object_storage_restore_jobs/{id}/continue.json', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='InlineResponse200149',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def set_obs_backup_job_class(self, id, set_obs_backup_job_class, **kwargs):  # noqa: E501
        """set_obs_backup_job_class  # noqa: E501

        Update a object storage backup job S3 storage class. only if Object storage destination is AWS S3.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.set_obs_backup_job_class(id, set_obs_backup_job_class, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: (required)
        :param SetObsBackupJobClass set_obs_backup_job_class: (required)
        :return: InlineResponse200138
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.set_obs_backup_job_class_with_http_info(id, set_obs_backup_job_class, **kwargs)  # noqa: E501
        else:
            (data) = self.set_obs_backup_job_class_with_http_info(id, set_obs_backup_job_class, **kwargs)  # noqa: E501
            return data

    def set_obs_backup_job_class_with_http_info(self, id, set_obs_backup_job_class, **kwargs):  # noqa: E501
        """set_obs_backup_job_class  # noqa: E501

        Update a object storage backup job S3 storage class. only if Object storage destination is AWS S3.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.set_obs_backup_job_class_with_http_info(id, set_obs_backup_job_class, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: (required)
        :param SetObsBackupJobClass set_obs_backup_job_class: (required)
        :return: InlineResponse200138
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['id', 'set_obs_backup_job_class']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method set_obs_backup_job_class" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'id' is set
        if self.api_client.client_side_validation and ('id' not in params or
                                                       params['id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `id` when calling `set_obs_backup_job_class`")  # noqa: E501
        # verify the required parameter 'set_obs_backup_job_class' is set
        if self.api_client.client_side_validation and ('set_obs_backup_job_class' not in params or
                                                       params['set_obs_backup_job_class'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `set_obs_backup_job_class` when calling `set_obs_backup_job_class`")  # noqa: E501

        if self.api_client.client_side_validation and ('id' in params and not re.search(r'^bkpjobs-[0-9a-f]{8}$', params['id'])):  # noqa: E501
            raise ValueError("Invalid value for parameter `id` when calling `set_obs_backup_job_class`, must conform to the pattern `/^bkpjobs-[0-9a-f]{8}$/`")  # noqa: E501
        collection_formats = {}

        path_params = {}
        if 'id' in params:
            path_params['id'] = params['id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'set_obs_backup_job_class' in params:
            body_params = params['set_obs_backup_job_class']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api_key']  # noqa: E501

        return self.api_client.call_api(
            '/object_storage_backup_jobs/{id}/update_storage_class.json', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='InlineResponse200138',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def update_ros_destination(self, id, update_ros_destination, **kwargs):  # noqa: E501
        """update_ros_destination  # noqa: E501

        Update a remote object storage.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.update_ros_destination(id, update_ros_destination, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: (required)
        :param UpdateRosDestination update_ros_destination: (required)
        :return: InlineResponse200130
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.update_ros_destination_with_http_info(id, update_ros_destination, **kwargs)  # noqa: E501
        else:
            (data) = self.update_ros_destination_with_http_info(id, update_ros_destination, **kwargs)  # noqa: E501
            return data

    def update_ros_destination_with_http_info(self, id, update_ros_destination, **kwargs):  # noqa: E501
        """update_ros_destination  # noqa: E501

        Update a remote object storage.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.update_ros_destination_with_http_info(id, update_ros_destination, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: (required)
        :param UpdateRosDestination update_ros_destination: (required)
        :return: InlineResponse200130
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['id', 'update_ros_destination']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method update_ros_destination" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'id' is set
        if self.api_client.client_side_validation and ('id' not in params or
                                                       params['id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `id` when calling `update_ros_destination`")  # noqa: E501
        # verify the required parameter 'update_ros_destination' is set
        if self.api_client.client_side_validation and ('update_ros_destination' not in params or
                                                       params['update_ros_destination'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `update_ros_destination` when calling `update_ros_destination`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'id' in params:
            path_params['id'] = params['id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'update_ros_destination' in params:
            body_params = params['update_ros_destination']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api_key']  # noqa: E501

        return self.api_client.call_api(
            '/object_storage_destinations/{id}.json', 'PUT',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='InlineResponse200130',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    Command Center operations

    Command Center operations  # noqa: E501

    OpenAPI spec version: 23.03-sp1
    Contact: support@zadarastorage.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from CommandCenter.configuration import Configuration


class InlineResponse2001Networking(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'be_allocated_count': 'int',
        'be_range_end': 'str',
        'be_range_start': 'str',
        'be_total_count': 'int',
        'cloud_id': 'int',
        'fe_allocated_count': 'int',
        'fe_range_end': 'str',
        'fe_range_start': 'str',
        'fe_total_count': 'int',
        'hb_allocated_count': 'int',
        'hb_range_end': 'str',
        'hb_range_start': 'str',
        'hb_total_count': 'int',
        'id': 'int'
    }

    attribute_map = {
        'be_allocated_count': 'be_allocated_count',
        'be_range_end': 'be_range_end',
        'be_range_start': 'be_range_start',
        'be_total_count': 'be_total_count',
        'cloud_id': 'cloud_id',
        'fe_allocated_count': 'fe_allocated_count',
        'fe_range_end': 'fe_range_end',
        'fe_range_start': 'fe_range_start',
        'fe_total_count': 'fe_total_count',
        'hb_allocated_count': 'hb_allocated_count',
        'hb_range_end': 'hb_range_end',
        'hb_range_start': 'hb_range_start',
        'hb_total_count': 'hb_total_count',
        'id': 'id'
    }

    def __init__(self, be_allocated_count=None, be_range_end=None, be_range_start=None, be_total_count=None, cloud_id=None, fe_allocated_count=None, fe_range_end=None, fe_range_start=None, fe_total_count=None, hb_allocated_count=None, hb_range_end=None, hb_range_start=None, hb_total_count=None, id=None, _configuration=None):  # noqa: E501
        """InlineResponse2001Networking - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._be_allocated_count = None
        self._be_range_end = None
        self._be_range_start = None
        self._be_total_count = None
        self._cloud_id = None
        self._fe_allocated_count = None
        self._fe_range_end = None
        self._fe_range_start = None
        self._fe_total_count = None
        self._hb_allocated_count = None
        self._hb_range_end = None
        self._hb_range_start = None
        self._hb_total_count = None
        self._id = None
        self.discriminator = None

        if be_allocated_count is not None:
            self.be_allocated_count = be_allocated_count
        if be_range_end is not None:
            self.be_range_end = be_range_end
        if be_range_start is not None:
            self.be_range_start = be_range_start
        if be_total_count is not None:
            self.be_total_count = be_total_count
        if cloud_id is not None:
            self.cloud_id = cloud_id
        if fe_allocated_count is not None:
            self.fe_allocated_count = fe_allocated_count
        if fe_range_end is not None:
            self.fe_range_end = fe_range_end
        if fe_range_start is not None:
            self.fe_range_start = fe_range_start
        if fe_total_count is not None:
            self.fe_total_count = fe_total_count
        if hb_allocated_count is not None:
            self.hb_allocated_count = hb_allocated_count
        if hb_range_end is not None:
            self.hb_range_end = hb_range_end
        if hb_range_start is not None:
            self.hb_range_start = hb_range_start
        if hb_total_count is not None:
            self.hb_total_count = hb_total_count
        if id is not None:
            self.id = id

    @property
    def be_allocated_count(self):
        """Gets the be_allocated_count of this InlineResponse2001Networking.  # noqa: E501


        :return: The be_allocated_count of this InlineResponse2001Networking.  # noqa: E501
        :rtype: int
        """
        return self._be_allocated_count

    @be_allocated_count.setter
    def be_allocated_count(self, be_allocated_count):
        """Sets the be_allocated_count of this InlineResponse2001Networking.


        :param be_allocated_count: The be_allocated_count of this InlineResponse2001Networking.  # noqa: E501
        :type: int
        """

        self._be_allocated_count = be_allocated_count

    @property
    def be_range_end(self):
        """Gets the be_range_end of this InlineResponse2001Networking.  # noqa: E501


        :return: The be_range_end of this InlineResponse2001Networking.  # noqa: E501
        :rtype: str
        """
        return self._be_range_end

    @be_range_end.setter
    def be_range_end(self, be_range_end):
        """Sets the be_range_end of this InlineResponse2001Networking.


        :param be_range_end: The be_range_end of this InlineResponse2001Networking.  # noqa: E501
        :type: str
        """

        self._be_range_end = be_range_end

    @property
    def be_range_start(self):
        """Gets the be_range_start of this InlineResponse2001Networking.  # noqa: E501


        :return: The be_range_start of this InlineResponse2001Networking.  # noqa: E501
        :rtype: str
        """
        return self._be_range_start

    @be_range_start.setter
    def be_range_start(self, be_range_start):
        """Sets the be_range_start of this InlineResponse2001Networking.


        :param be_range_start: The be_range_start of this InlineResponse2001Networking.  # noqa: E501
        :type: str
        """

        self._be_range_start = be_range_start

    @property
    def be_total_count(self):
        """Gets the be_total_count of this InlineResponse2001Networking.  # noqa: E501


        :return: The be_total_count of this InlineResponse2001Networking.  # noqa: E501
        :rtype: int
        """
        return self._be_total_count

    @be_total_count.setter
    def be_total_count(self, be_total_count):
        """Sets the be_total_count of this InlineResponse2001Networking.


        :param be_total_count: The be_total_count of this InlineResponse2001Networking.  # noqa: E501
        :type: int
        """

        self._be_total_count = be_total_count

    @property
    def cloud_id(self):
        """Gets the cloud_id of this InlineResponse2001Networking.  # noqa: E501


        :return: The cloud_id of this InlineResponse2001Networking.  # noqa: E501
        :rtype: int
        """
        return self._cloud_id

    @cloud_id.setter
    def cloud_id(self, cloud_id):
        """Sets the cloud_id of this InlineResponse2001Networking.


        :param cloud_id: The cloud_id of this InlineResponse2001Networking.  # noqa: E501
        :type: int
        """

        self._cloud_id = cloud_id

    @property
    def fe_allocated_count(self):
        """Gets the fe_allocated_count of this InlineResponse2001Networking.  # noqa: E501


        :return: The fe_allocated_count of this InlineResponse2001Networking.  # noqa: E501
        :rtype: int
        """
        return self._fe_allocated_count

    @fe_allocated_count.setter
    def fe_allocated_count(self, fe_allocated_count):
        """Sets the fe_allocated_count of this InlineResponse2001Networking.


        :param fe_allocated_count: The fe_allocated_count of this InlineResponse2001Networking.  # noqa: E501
        :type: int
        """

        self._fe_allocated_count = fe_allocated_count

    @property
    def fe_range_end(self):
        """Gets the fe_range_end of this InlineResponse2001Networking.  # noqa: E501


        :return: The fe_range_end of this InlineResponse2001Networking.  # noqa: E501
        :rtype: str
        """
        return self._fe_range_end

    @fe_range_end.setter
    def fe_range_end(self, fe_range_end):
        """Sets the fe_range_end of this InlineResponse2001Networking.


        :param fe_range_end: The fe_range_end of this InlineResponse2001Networking.  # noqa: E501
        :type: str
        """

        self._fe_range_end = fe_range_end

    @property
    def fe_range_start(self):
        """Gets the fe_range_start of this InlineResponse2001Networking.  # noqa: E501


        :return: The fe_range_start of this InlineResponse2001Networking.  # noqa: E501
        :rtype: str
        """
        return self._fe_range_start

    @fe_range_start.setter
    def fe_range_start(self, fe_range_start):
        """Sets the fe_range_start of this InlineResponse2001Networking.


        :param fe_range_start: The fe_range_start of this InlineResponse2001Networking.  # noqa: E501
        :type: str
        """

        self._fe_range_start = fe_range_start

    @property
    def fe_total_count(self):
        """Gets the fe_total_count of this InlineResponse2001Networking.  # noqa: E501


        :return: The fe_total_count of this InlineResponse2001Networking.  # noqa: E501
        :rtype: int
        """
        return self._fe_total_count

    @fe_total_count.setter
    def fe_total_count(self, fe_total_count):
        """Sets the fe_total_count of this InlineResponse2001Networking.


        :param fe_total_count: The fe_total_count of this InlineResponse2001Networking.  # noqa: E501
        :type: int
        """

        self._fe_total_count = fe_total_count

    @property
    def hb_allocated_count(self):
        """Gets the hb_allocated_count of this InlineResponse2001Networking.  # noqa: E501


        :return: The hb_allocated_count of this InlineResponse2001Networking.  # noqa: E501
        :rtype: int
        """
        return self._hb_allocated_count

    @hb_allocated_count.setter
    def hb_allocated_count(self, hb_allocated_count):
        """Sets the hb_allocated_count of this InlineResponse2001Networking.


        :param hb_allocated_count: The hb_allocated_count of this InlineResponse2001Networking.  # noqa: E501
        :type: int
        """

        self._hb_allocated_count = hb_allocated_count

    @property
    def hb_range_end(self):
        """Gets the hb_range_end of this InlineResponse2001Networking.  # noqa: E501


        :return: The hb_range_end of this InlineResponse2001Networking.  # noqa: E501
        :rtype: str
        """
        return self._hb_range_end

    @hb_range_end.setter
    def hb_range_end(self, hb_range_end):
        """Sets the hb_range_end of this InlineResponse2001Networking.


        :param hb_range_end: The hb_range_end of this InlineResponse2001Networking.  # noqa: E501
        :type: str
        """

        self._hb_range_end = hb_range_end

    @property
    def hb_range_start(self):
        """Gets the hb_range_start of this InlineResponse2001Networking.  # noqa: E501


        :return: The hb_range_start of this InlineResponse2001Networking.  # noqa: E501
        :rtype: str
        """
        return self._hb_range_start

    @hb_range_start.setter
    def hb_range_start(self, hb_range_start):
        """Sets the hb_range_start of this InlineResponse2001Networking.


        :param hb_range_start: The hb_range_start of this InlineResponse2001Networking.  # noqa: E501
        :type: str
        """

        self._hb_range_start = hb_range_start

    @property
    def hb_total_count(self):
        """Gets the hb_total_count of this InlineResponse2001Networking.  # noqa: E501


        :return: The hb_total_count of this InlineResponse2001Networking.  # noqa: E501
        :rtype: int
        """
        return self._hb_total_count

    @hb_total_count.setter
    def hb_total_count(self, hb_total_count):
        """Sets the hb_total_count of this InlineResponse2001Networking.


        :param hb_total_count: The hb_total_count of this InlineResponse2001Networking.  # noqa: E501
        :type: int
        """

        self._hb_total_count = hb_total_count

    @property
    def id(self):
        """Gets the id of this InlineResponse2001Networking.  # noqa: E501


        :return: The id of this InlineResponse2001Networking.  # noqa: E501
        :rtype: int
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this InlineResponse2001Networking.


        :param id: The id of this InlineResponse2001Networking.  # noqa: E501
        :type: int
        """

        self._id = id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(InlineResponse2001Networking, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, InlineResponse2001Networking):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, InlineResponse2001Networking):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Zadara VPSA Object Storage REST API

    # Overview  This document outlines the methods available for administrating your VPSA&#174; Object Storage. The API supports form-encoded, JSON, and XML requests, and can return either JSON or XML responses.  ## Usage  The majority of the APIs available require authentication which requires an API token to use. You can retrieve this token through the Users section of your VPSA, or through the API using the \"Return a user's access key\" API in the Users Section below.  ## Authentication Methods  The authentication token can be passed either through the access_key parameter inside of the body of the REST API request, or through the X-Access-Key header. Alternately, you can use the username and password parameters for authentication, but we do not recommend this method for anything other than possibly retrieving an API key.  By default , all operations are allowed only to VPSA Object Storage admin. Some actions are allowed by an account admin and they will be marked on the action's header  ## Timeouts  By default, all operations that don't complete within five seconds will return a message informing you that the action may take some time to complete. When using the API, this can cause some actions, such as adding drives to storage policy, to be undesirably asynchronous. You can specify your own timeout with the timeout parameter, in seconds, and a timeout value of -1 specifies an infinite timeout.  ## Metering API  Metering information can be retrieved using the VPSA Object Storage API for the following components:  - Accounts - Users - Drives - Virtual Controllers - Load Balancer Groups - Storage Policies  Metering information returned by the API is subject to the following constraints:  - 10 seconds interval - 1 hour range - 1 minute interval - 1 day range - 1 hour interval - 30 days range  Values outside the accepted range will be returned as 0.  ## Questions  If you have any questions or need support involving the REST API, please contact for assistance.   # noqa: E501

    OpenAPI spec version: 23.03-sp1
    Contact: support@zadarastorage.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from Zios.configuration import Configuration


class InlineResponse2008ResponseRequests(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'id': 'int',
        'arguments': 'InlineResponse2008ResponseArguments',
        'action': 'str',
        'decided_by': 'str',
        'decided_at': 'str',
        'requested_at': 'str'
    }

    attribute_map = {
        'id': 'id',
        'arguments': 'arguments',
        'action': 'action',
        'decided_by': 'decided_by',
        'decided_at': 'decided_at',
        'requested_at': 'requested_at'
    }

    def __init__(self, id=None, arguments=None, action=None, decided_by=None, decided_at=None, requested_at=None, _configuration=None):  # noqa: E501
        """InlineResponse2008ResponseRequests - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._id = None
        self._arguments = None
        self._action = None
        self._decided_by = None
        self._decided_at = None
        self._requested_at = None
        self.discriminator = None

        if id is not None:
            self.id = id
        if arguments is not None:
            self.arguments = arguments
        if action is not None:
            self.action = action
        if decided_by is not None:
            self.decided_by = decided_by
        if decided_at is not None:
            self.decided_at = decided_at
        if requested_at is not None:
            self.requested_at = requested_at

    @property
    def id(self):
        """Gets the id of this InlineResponse2008ResponseRequests.  # noqa: E501


        :return: The id of this InlineResponse2008ResponseRequests.  # noqa: E501
        :rtype: int
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this InlineResponse2008ResponseRequests.


        :param id: The id of this InlineResponse2008ResponseRequests.  # noqa: E501
        :type: int
        """

        self._id = id

    @property
    def arguments(self):
        """Gets the arguments of this InlineResponse2008ResponseRequests.  # noqa: E501


        :return: The arguments of this InlineResponse2008ResponseRequests.  # noqa: E501
        :rtype: InlineResponse2008ResponseArguments
        """
        return self._arguments

    @arguments.setter
    def arguments(self, arguments):
        """Sets the arguments of this InlineResponse2008ResponseRequests.


        :param arguments: The arguments of this InlineResponse2008ResponseRequests.  # noqa: E501
        :type: InlineResponse2008ResponseArguments
        """

        self._arguments = arguments

    @property
    def action(self):
        """Gets the action of this InlineResponse2008ResponseRequests.  # noqa: E501


        :return: The action of this InlineResponse2008ResponseRequests.  # noqa: E501
        :rtype: str
        """
        return self._action

    @action.setter
    def action(self, action):
        """Sets the action of this InlineResponse2008ResponseRequests.


        :param action: The action of this InlineResponse2008ResponseRequests.  # noqa: E501
        :type: str
        """

        self._action = action

    @property
    def decided_by(self):
        """Gets the decided_by of this InlineResponse2008ResponseRequests.  # noqa: E501


        :return: The decided_by of this InlineResponse2008ResponseRequests.  # noqa: E501
        :rtype: str
        """
        return self._decided_by

    @decided_by.setter
    def decided_by(self, decided_by):
        """Sets the decided_by of this InlineResponse2008ResponseRequests.


        :param decided_by: The decided_by of this InlineResponse2008ResponseRequests.  # noqa: E501
        :type: str
        """

        self._decided_by = decided_by

    @property
    def decided_at(self):
        """Gets the decided_at of this InlineResponse2008ResponseRequests.  # noqa: E501


        :return: The decided_at of this InlineResponse2008ResponseRequests.  # noqa: E501
        :rtype: str
        """
        return self._decided_at

    @decided_at.setter
    def decided_at(self, decided_at):
        """Sets the decided_at of this InlineResponse2008ResponseRequests.


        :param decided_at: The decided_at of this InlineResponse2008ResponseRequests.  # noqa: E501
        :type: str
        """

        self._decided_at = decided_at

    @property
    def requested_at(self):
        """Gets the requested_at of this InlineResponse2008ResponseRequests.  # noqa: E501


        :return: The requested_at of this InlineResponse2008ResponseRequests.  # noqa: E501
        :rtype: str
        """
        return self._requested_at

    @requested_at.setter
    def requested_at(self, requested_at):
        """Sets the requested_at of this InlineResponse2008ResponseRequests.


        :param requested_at: The requested_at of this InlineResponse2008ResponseRequests.  # noqa: E501
        :type: str
        """

        self._requested_at = requested_at

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(InlineResponse2008ResponseRequests, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, InlineResponse2008ResponseRequests):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, InlineResponse2008ResponseRequests):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Zadara VPSA Storage Array REST API

     # Overview  This document outlines the methods available for administrating your Zadara Storage VPSA&#8482;. The Zadara Storage Array REST API   supports form-encoded, JSON, and XML requests, and can return either JSON or XML responses.  ## Usage  The majority of the APIs available require authentication which requires an API token to use. You can retrieve this token through the   Users section of your VPSA, or through the API using the \"Return a user's access key\" API in the Users Section below.  ## Authentication Methods  The authentication token can be passed either through the access_key parameter inside of the body of the REST API request, or   through the X-Access-Key header.  ## Timeouts  By default, all operations that don't complete within five seconds will return a message informing you that the action may take some  time to complete. When using the API, this can cause some actions, such as large volume creation, to be undesirably asynchronous.  You can specify your own timeout with the timeout parameter, in seconds, and a timeout value of -1 specifies an infinite timeout.  ## Specific Fields For Product  Some of the fields/actions used in the API should be used only for a specific product. The following tags are used to mark which   product responds to the fields/actions  VPSA Flash Array  VPSA Storage Array - Hybrid VPSA  ## Questions  If you have any questions or need support involving the REST API, please contact for assistance.   # noqa: E501

    OpenAPI spec version: 23.03-sp1
    Contact: support@zadarastorage.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from Vpsa.configuration import Configuration


class CreateRosDestination(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'name': 'str',
        'type': 'str',
        'bucket': 'str',
        'endpoint': 'str',
        'username': 'str',
        'password': 'str',
        'connect_via': 'str',
        'allow_lifecycle_policies': 'bool',
        'proxyhost': 'str',
        'proxyport': 'str',
        'proxyuser': 'str',
        'proxypassword': 'str'
    }

    attribute_map = {
        'name': 'name',
        'type': 'type',
        'bucket': 'bucket',
        'endpoint': 'endpoint',
        'username': 'username',
        'password': 'password',
        'connect_via': 'connectVia',
        'allow_lifecycle_policies': 'allow_lifecycle_policies',
        'proxyhost': 'proxyhost',
        'proxyport': 'proxyport',
        'proxyuser': 'proxyuser',
        'proxypassword': 'proxypassword'
    }

    def __init__(self, name=None, type=None, bucket=None, endpoint=None, username=None, password=None, connect_via=None, allow_lifecycle_policies=None, proxyhost=None, proxyport=None, proxyuser=None, proxypassword=None, _configuration=None):  # noqa: E501
        """CreateRosDestination - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._name = None
        self._type = None
        self._bucket = None
        self._endpoint = None
        self._username = None
        self._password = None
        self._connect_via = None
        self._allow_lifecycle_policies = None
        self._proxyhost = None
        self._proxyport = None
        self._proxyuser = None
        self._proxypassword = None
        self.discriminator = None

        self.name = name
        self.type = type
        self.bucket = bucket
        self.endpoint = endpoint
        self.username = username
        self.password = password
        self.connect_via = connect_via
        self.allow_lifecycle_policies = allow_lifecycle_policies
        if proxyhost is not None:
            self.proxyhost = proxyhost
        if proxyport is not None:
            self.proxyport = proxyport
        if proxyuser is not None:
            self.proxyuser = proxyuser
        if proxypassword is not None:
            self.proxypassword = proxypassword

    @property
    def name(self):
        """Gets the name of this CreateRosDestination.  # noqa: E501

        Display Name for remote object storage  # noqa: E501

        :return: The name of this CreateRosDestination.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this CreateRosDestination.

        Display Name for remote object storage  # noqa: E501

        :param name: The name of this CreateRosDestination.  # noqa: E501
        :type: str
        """
        if self._configuration.client_side_validation and name is None:
            raise ValueError("Invalid value for `name`, must not be `None`")  # noqa: E501

        self._name = name

    @property
    def type(self):
        """Gets the type of this CreateRosDestination.  # noqa: E501

        Type for remote object storage.  # noqa: E501

        :return: The type of this CreateRosDestination.  # noqa: E501
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this CreateRosDestination.

        Type for remote object storage.  # noqa: E501

        :param type: The type of this CreateRosDestination.  # noqa: E501
        :type: str
        """
        if self._configuration.client_side_validation and type is None:
            raise ValueError("Invalid value for `type`, must not be `None`")  # noqa: E501
        allowed_values = ["AWS_S3", "GCS_S3", "ZIOS_S3", "AZURE"]  # noqa: E501
        if (self._configuration.client_side_validation and
                type not in allowed_values):
            raise ValueError(
                "Invalid value for `type` ({0}), must be one of {1}"  # noqa: E501
                .format(type, allowed_values)
            )

        self._type = type

    @property
    def bucket(self):
        """Gets the bucket of this CreateRosDestination.  # noqa: E501

        remote object storage bucket name / Azure cloud container name  # noqa: E501

        :return: The bucket of this CreateRosDestination.  # noqa: E501
        :rtype: str
        """
        return self._bucket

    @bucket.setter
    def bucket(self, bucket):
        """Sets the bucket of this CreateRosDestination.

        remote object storage bucket name / Azure cloud container name  # noqa: E501

        :param bucket: The bucket of this CreateRosDestination.  # noqa: E501
        :type: str
        """
        if self._configuration.client_side_validation and bucket is None:
            raise ValueError("Invalid value for `bucket`, must not be `None`")  # noqa: E501

        self._bucket = bucket

    @property
    def endpoint(self):
        """Gets the endpoint of this CreateRosDestination.  # noqa: E501

        Endpoint for remote object storage (use 'storage.googleapis.com' for Google cloud, use 'blob.core.windows.net' for Azure cloud).  # noqa: E501

        :return: The endpoint of this CreateRosDestination.  # noqa: E501
        :rtype: str
        """
        return self._endpoint

    @endpoint.setter
    def endpoint(self, endpoint):
        """Sets the endpoint of this CreateRosDestination.

        Endpoint for remote object storage (use 'storage.googleapis.com' for Google cloud, use 'blob.core.windows.net' for Azure cloud).  # noqa: E501

        :param endpoint: The endpoint of this CreateRosDestination.  # noqa: E501
        :type: str
        """
        if self._configuration.client_side_validation and endpoint is None:
            raise ValueError("Invalid value for `endpoint`, must not be `None`")  # noqa: E501

        self._endpoint = endpoint

    @property
    def username(self):
        """Gets the username of this CreateRosDestination.  # noqa: E501

        Access Key ID for remote object storage / Account in Azure cloud  # noqa: E501

        :return: The username of this CreateRosDestination.  # noqa: E501
        :rtype: str
        """
        return self._username

    @username.setter
    def username(self, username):
        """Sets the username of this CreateRosDestination.

        Access Key ID for remote object storage / Account in Azure cloud  # noqa: E501

        :param username: The username of this CreateRosDestination.  # noqa: E501
        :type: str
        """
        if self._configuration.client_side_validation and username is None:
            raise ValueError("Invalid value for `username`, must not be `None`")  # noqa: E501

        self._username = username

    @property
    def password(self):
        """Gets the password of this CreateRosDestination.  # noqa: E501

        Secret Access Key for remote object storage / Storage account key in Azure cloud.  # noqa: E501

        :return: The password of this CreateRosDestination.  # noqa: E501
        :rtype: str
        """
        return self._password

    @password.setter
    def password(self, password):
        """Sets the password of this CreateRosDestination.

        Secret Access Key for remote object storage / Storage account key in Azure cloud.  # noqa: E501

        :param password: The password of this CreateRosDestination.  # noqa: E501
        :type: str
        """
        if self._configuration.client_side_validation and password is None:
            raise ValueError("Invalid value for `password`, must not be `None`")  # noqa: E501

        self._password = password

    @property
    def connect_via(self):
        """Gets the connect_via of this CreateRosDestination.  # noqa: E501

        Connection method to Azure cloud.  # noqa: E501

        :return: The connect_via of this CreateRosDestination.  # noqa: E501
        :rtype: str
        """
        return self._connect_via

    @connect_via.setter
    def connect_via(self, connect_via):
        """Sets the connect_via of this CreateRosDestination.

        Connection method to Azure cloud.  # noqa: E501

        :param connect_via: The connect_via of this CreateRosDestination.  # noqa: E501
        :type: str
        """
        if self._configuration.client_side_validation and connect_via is None:
            raise ValueError("Invalid value for `connect_via`, must not be `None`")  # noqa: E501
        allowed_values = ["fe", "public"]  # noqa: E501
        if (self._configuration.client_side_validation and
                connect_via not in allowed_values):
            raise ValueError(
                "Invalid value for `connect_via` ({0}), must be one of {1}"  # noqa: E501
                .format(connect_via, allowed_values)
            )

        self._connect_via = connect_via

    @property
    def allow_lifecycle_policies(self):
        """Gets the allow_lifecycle_policies of this CreateRosDestination.  # noqa: E501

        Allow bucket to have lifecycle policies - use 'true'.  # noqa: E501

        :return: The allow_lifecycle_policies of this CreateRosDestination.  # noqa: E501
        :rtype: bool
        """
        return self._allow_lifecycle_policies

    @allow_lifecycle_policies.setter
    def allow_lifecycle_policies(self, allow_lifecycle_policies):
        """Sets the allow_lifecycle_policies of this CreateRosDestination.

        Allow bucket to have lifecycle policies - use 'true'.  # noqa: E501

        :param allow_lifecycle_policies: The allow_lifecycle_policies of this CreateRosDestination.  # noqa: E501
        :type: bool
        """
        if self._configuration.client_side_validation and allow_lifecycle_policies is None:
            raise ValueError("Invalid value for `allow_lifecycle_policies`, must not be `None`")  # noqa: E501

        self._allow_lifecycle_policies = allow_lifecycle_policies

    @property
    def proxyhost(self):
        """Gets the proxyhost of this CreateRosDestination.  # noqa: E501

        Proxy host  # noqa: E501

        :return: The proxyhost of this CreateRosDestination.  # noqa: E501
        :rtype: str
        """
        return self._proxyhost

    @proxyhost.setter
    def proxyhost(self, proxyhost):
        """Sets the proxyhost of this CreateRosDestination.

        Proxy host  # noqa: E501

        :param proxyhost: The proxyhost of this CreateRosDestination.  # noqa: E501
        :type: str
        """

        self._proxyhost = proxyhost

    @property
    def proxyport(self):
        """Gets the proxyport of this CreateRosDestination.  # noqa: E501

        Port for proxy  # noqa: E501

        :return: The proxyport of this CreateRosDestination.  # noqa: E501
        :rtype: str
        """
        return self._proxyport

    @proxyport.setter
    def proxyport(self, proxyport):
        """Sets the proxyport of this CreateRosDestination.

        Port for proxy  # noqa: E501

        :param proxyport: The proxyport of this CreateRosDestination.  # noqa: E501
        :type: str
        """

        self._proxyport = proxyport

    @property
    def proxyuser(self):
        """Gets the proxyuser of this CreateRosDestination.  # noqa: E501

        Username for proxy  # noqa: E501

        :return: The proxyuser of this CreateRosDestination.  # noqa: E501
        :rtype: str
        """
        return self._proxyuser

    @proxyuser.setter
    def proxyuser(self, proxyuser):
        """Sets the proxyuser of this CreateRosDestination.

        Username for proxy  # noqa: E501

        :param proxyuser: The proxyuser of this CreateRosDestination.  # noqa: E501
        :type: str
        """

        self._proxyuser = proxyuser

    @property
    def proxypassword(self):
        """Gets the proxypassword of this CreateRosDestination.  # noqa: E501

        Password for proxy  # noqa: E501

        :return: The proxypassword of this CreateRosDestination.  # noqa: E501
        :rtype: str
        """
        return self._proxypassword

    @proxypassword.setter
    def proxypassword(self, proxypassword):
        """Sets the proxypassword of this CreateRosDestination.

        Password for proxy  # noqa: E501

        :param proxypassword: The proxypassword of this CreateRosDestination.  # noqa: E501
        :type: str
        """

        self._proxypassword = proxypassword

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(CreateRosDestination, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CreateRosDestination):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, CreateRosDestination):
            return True

        return self.to_dict() != other.to_dict()
